==> qmmp_0.6.3.orig.tar.gz: qmmp-0.6.3/src/plugins/General/notifier/translations/notifier_plugin_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>NotifierFactory</name>
    <message>
        <location filename="../notifierfactory.cpp" line="30"/>
        <source>Notifier Plugin</source>
        <translation>Модуль уведомлений</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="50"/>
        <source>About Notifier Plugin</source>
        <translation>О модуле уведомлений</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="51"/>
        <source>Qmmp Notifier Plugin</source>
        <translation>Модуль уведомлений для Qmmp</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Разработчик: Илья Котов &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>PopupWidget</name>
    <message>
        <location filename="../popupwidget.cpp" line="127"/>
        <source>Volume:</source>
        <translation>Громкость:</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Notifier Plugin Settings</source>
        <translation>Настройки модуля уведомлений</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="141"/>
        <source>Transparency:</source>
        <translation>Прозрачность:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="105"/>
        <source>Notification Template</source>
        <translation>Шаблон уведомления</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="368"/>
        <source>Psi Notification</source>
        <translation>Уведомление Psi</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="380"/>
        <source>Enable Psi notification</source>
        <translation>Включить уведомление Psi</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>Desktop Notification</source>
        <translation>Сообщение на рабочем столе</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="82"/>
        <source>Delay (ms):</source>
        <translation>Задежка (мс):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="321"/>
        <source>Position</source>
        <translation>Положение</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="343"/>
        <source>Edit template</source>
        <translation>Редактировать шаблон</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <source>Song change notification</source>
        <translation>Уведомление о смене песни</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="48"/>
        <source>Volume change notification</source>
        <translation>Уведомление о смене громкости</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="134"/>
        <location filename="../settingsdialog.ui" line="164"/>
        <source>0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Font:</source>
        <translation>Шрифт:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="108"/>
        <source>Cover size:</source>
        <translation>Размер обложки:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="75"/>
        <source>...</source>
        <translation></translation>
    </message>
</context>
</TS>

==> qmmp_0.7.4.orig.tar.gz: qmmp-0.7.4/src/plugins/General/notifier/translations/notifier_plugin_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>NotifierFactory</name>
    <message>
        <location filename="../notifierfactory.cpp" line="30"/>
        <source>Notifier Plugin</source>
        <translation>Модуль уведомлений</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="50"/>
        <source>About Notifier Plugin</source>
        <translation>О модуле уведомлений</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="51"/>
        <source>Qmmp Notifier Plugin</source>
        <translation>Модуль уведомлений для Qmmp</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Разработчик: Илья Котов &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>PopupWidget</name>
    <message>
        <location filename="../popupwidget.cpp" line="127"/>
        <source>Volume:</source>
        <translation>Громкость:</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Notifier Plugin Settings</source>
        <translation>Настройки модуля уведомлений</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="75"/>
        <source>Transparency:</source>
        <translation>Прозрачность:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="107"/>
        <source>Notification Template</source>
        <translation>Шаблон уведомления</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="378"/>
        <source>Psi Notification</source>
        <translation>Уведомление Psi</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="390"/>
        <source>Enable Psi notification</source>
        <translation>Включить уведомление Psi</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>Desktop Notification</source>
        <translation>Сообщение на рабочем столе</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="332"/>
        <source>Delay (ms):</source>
        <translation>Задежка (мс):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="219"/>
        <source>Position</source>
        <translation>Положение</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="241"/>
        <source>Edit template</source>
        <translation>Редактировать шаблон</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="361"/>
        <source>Playback resume notification</source>
        <translation>Уведомлять о продолжении воспроизведения</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="368"/>
        <source>Song change notification</source>
        <translation>Уведомление о смене песни</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="325"/>
        <source>Volume change notification</source>
        <translation>Уведомление о смене громкости</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="68"/>
        <location filename="../settingsdialog.ui" line="279"/>
        <source>0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <source>Font:</source>
        <translation>Шрифт:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="299"/>
        <source>Cover size:</source>
        <translation>Размер обложки:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <source>...</source>
        <translation></translation>
    </message>
</context>
</TS>
